@@ -157,6 +157,8 @@ class AdminServer:
         resp: dict[str, Any] = {
             "name": cluster.name,
             "default_quota": {},
+            "default_role": str(cluster.default_role),
+            "maintenance": cluster.maintenance,
         }
         if cluster.default_credits:
             resp["default_credits"] = str(cluster.default_credits)
@@ -187,6 +189,10 @@ class AdminServer:
                     default_quota_raw.get("total_running_jobs")
                 )
             ),
+            default_role=ClusterUserRoleType(
+                payload.get("default_role", ClusterUserRoleType.USER.value)
+            ),
+            maintenance=payload.get("maintenance", False),
         )
         self.clusters.append(new_cluster)
         return aiohttp.web.json_response(self._serialize_cluster(new_cluster))
@@ -211,6 +217,10 @@ class AdminServer:
                     default_quota_raw.get("total_running_jobs")
                 )
             ),
+            default_role=ClusterUserRoleType(
+                payload.get("default_role", ClusterUserRoleType.USER.value)
+            ),
+            maintenance=payload.get("maintenance", False),
         )
         self.clusters = [
             cluster for cluster in self.clusters if cluster.name != changed_cluster.name
@@ -609,6 +619,8 @@ class AdminServer:
                 "spent_credits": str(org_cluster.balance.spent_credits),
             },
             "default_quota": {},
+            "default_role": str(org_cluster.default_role),
+            "maintenance": org_cluster.maintenance,
         }
         if org_cluster.quota.total_running_jobs is not None:
             res["quota"]["total_running_jobs"] = org_cluster.quota.total_running_jobs
@@ -620,8 +632,8 @@ class AdminServer:
             res["default_quota"][
                 "total_running_jobs"
             ] = org_cluster.default_quota.total_running_jobs
-        if org_cluster.storage_size_mb is not None:
-            res["storage_size_mb"] = org_cluster.storage_size_mb
+        if org_cluster.storage_size is not None:
+            res["storage_size"] = org_cluster.storage_size
         return res
 
     async def handle_org_cluster_post(
@@ -652,7 +664,11 @@ class AdminServer:
             default_credits=Decimal(default_credits_raw)
             if default_credits_raw
             else None,
-            storage_size_mb=payload.get("storage_size_mb"),
+            default_role=ClusterUserRoleType(
+                payload.get("default_role", ClusterUserRoleType.USER.value)
+            ),
+            storage_size=payload.get("storage_size"),
+            maintenance=payload.get("maintenance", False),
         )
         self.org_clusters.append(new_org_cluster)
         return aiohttp.web.json_response(
@@ -690,6 +706,10 @@ class AdminServer:
             default_credits=Decimal(default_credits_raw)
             if default_credits_raw
             else None,
+            default_role=ClusterUserRoleType(
+                payload.get("default_role", ClusterUserRoleType.USER.value)
+            ),
+            maintenance=payload["maintenance"],
         )
         assert new_org_cluster.org_name == org_name
         self.org_clusters = [
@@ -767,6 +787,9 @@ class AdminServer:
                     default_credits=Decimal(default_credits_raw)
                     if default_credits_raw
                     else None,
+                    default_role=ClusterUserRoleType(
+                        payload.get("default_role", ClusterUserRoleType.USER.value)
+                    ),
                 )
                 self.org_clusters[index] = org_cluster
                 return aiohttp.web.json_response(
