@@ -117,11 +117,13 @@ class TestAdminClient:
                 name="cluster1",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
             Cluster(
                 name="cluster2",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -218,6 +220,7 @@ class TestAdminClient:
         assert len(mock_admin_server.clusters) == 1
         created_cluster = mock_admin_server.clusters[0]
         assert created_cluster.name == "name"
+        assert not created_cluster.maintenance
 
     async def test_create_cluster_with_defaults(
         self, mock_admin_server: AdminServer
@@ -227,6 +230,7 @@ class TestAdminClient:
                 name="name",
                 default_credits=Decimal(20),
                 default_quota=Quota(total_running_jobs=42),
+                default_role=ClusterUserRoleType.MANAGER,
             )
 
         assert len(mock_admin_server.clusters) == 1
@@ -234,12 +238,29 @@ class TestAdminClient:
         assert created_cluster.name == "name"
         assert created_cluster.default_credits == Decimal(20)
         assert created_cluster.default_quota == Quota(total_running_jobs=42)
+        assert created_cluster.default_role == ClusterUserRoleType.MANAGER
+
+    async def test_create_cluster_with_maintenance(
+        self, mock_admin_server: AdminServer
+    ) -> None:
+        async with AdminClient(base_url=mock_admin_server.url) as client:
+            await client.create_cluster(
+                name="name",
+                maintenance=True,
+            )
+
+        assert len(mock_admin_server.clusters) == 1
+        created_cluster = mock_admin_server.clusters[0]
+        assert created_cluster.name == "name"
+        assert created_cluster.maintenance
 
     async def test_update_cluster(self, mock_admin_server: AdminServer) -> None:
         cluster = Cluster(
             name="name",
             default_credits=Decimal(20),
             default_quota=Quota(total_running_jobs=42),
+            maintenance=True,
+            default_role=ClusterUserRoleType.USER,
         )
 
         async with AdminClient(base_url=mock_admin_server.url) as client:
@@ -256,11 +277,13 @@ class TestAdminClient:
                 name="name",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
             Cluster(
                 name="name2",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
 
@@ -276,11 +299,13 @@ class TestAdminClient:
                 name="name",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
             Cluster(
                 name="name2",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
 
@@ -297,11 +322,13 @@ class TestAdminClient:
                 name="name",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
             Cluster(
                 name="name2",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
 
@@ -427,6 +454,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -472,6 +500,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -515,6 +544,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -563,6 +593,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -603,6 +634,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.orgs = [
@@ -790,12 +822,13 @@ class TestAdminClient:
                 name="test_org",
             )
             res_org = await client.create_org_cluster(
-                cluster_name="test", org_name="test_org", storage_size_mb=1024
+                cluster_name="test", org_name="test_org", storage_size=1024
             )
 
         assert res_org.cluster_name == "test"
         assert res_org.org_name == "test_org"
-        assert res_org.storage_size_mb == 1024
+        assert res_org.storage_size == 1024
+        assert not res_org.maintenance
 
         assert mock_admin_server.org_clusters == [res_org]
 
@@ -812,12 +845,34 @@ class TestAdminClient:
                 org_name="test_org",
                 default_credits=Decimal(20),
                 default_quota=Quota(total_running_jobs=42),
+                default_role=ClusterUserRoleType.MEMBER,
             )
 
         assert res_org.cluster_name == "test"
         assert res_org.org_name == "test_org"
         assert res_org.default_credits == Decimal(20)
         assert res_org.default_quota == Quota(total_running_jobs=42)
+        assert res_org.default_role == ClusterUserRoleType.MEMBER
+
+        assert mock_admin_server.org_clusters == [res_org]
+
+    async def test_create_org_cluster_with_maintenance(
+        self, mock_admin_server: AdminServer
+    ) -> None:
+        async with AdminClient(base_url=mock_admin_server.url) as client:
+            await client.create_cluster(name="test")
+            await client.create_org(
+                name="test_org",
+            )
+            res_org = await client.create_org_cluster(
+                cluster_name="test",
+                org_name="test_org",
+                maintenance=True,
+            )
+
+        assert res_org.cluster_name == "test"
+        assert res_org.org_name == "test_org"
+        assert res_org.maintenance
 
         assert mock_admin_server.org_clusters == [res_org]
 
@@ -835,6 +890,7 @@ class TestAdminClient:
                 balance=Balance(credits=Decimal(22)),
                 default_credits=Decimal(20),
                 default_quota=Quota(total_running_jobs=42),
+                maintenance=True,
             )
             await client.update_org_cluster(new_org_cluster)
 
@@ -854,6 +910,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
@@ -891,6 +948,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
@@ -933,6 +991,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
@@ -969,6 +1028,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -1011,6 +1071,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -1049,6 +1110,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.cluster_users = [
@@ -1083,6 +1145,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.orgs = [
@@ -1132,6 +1195,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.orgs = [
@@ -1181,6 +1245,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.orgs = [
@@ -1215,6 +1280,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
 
@@ -1243,6 +1309,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
@@ -1260,9 +1327,11 @@ class TestAdminClient:
                 org_name="org",
                 default_quota=Quota(total_running_jobs=20),
                 default_credits=Decimal(42),
+                default_role=ClusterUserRoleType.MEMBER,
             )
             assert org_cluster.default_quota.total_running_jobs == 20
             assert org_cluster.default_credits == Decimal(42)
+            assert org_cluster.default_role == ClusterUserRoleType.MEMBER
 
             server_org_cluster = mock_admin_server.org_clusters[0]
             assert org_cluster == server_org_cluster
@@ -1280,6 +1349,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
@@ -1319,6 +1389,7 @@ class TestAdminClient:
                 name="cluster",
                 default_credits=None,
                 default_quota=Quota(),
+                default_role=ClusterUserRoleType.USER,
             ),
         ]
         mock_admin_server.org_clusters = [
